Uses of Class org.openqa.selenium.server.BrowserConfigurationOptions (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.BrowserConfigurationOptions

Packages that use BrowserConfigurationOptions
org.openqa.selenium.server | Provides the core Selenium Server classes.
org.openqa.selenium.server.browserlaunchers | Provides classes to launch and kill browsers.
org.openqa.selenium.server.htmlrunner | Provides classes to launch Selenium Core HTML test suites and handle their test results.

Uses of BrowserConfigurationOptions in org.openqa.selenium.server

Methods in org.openqa.selenium.server with parameters of type BrowserConfigurationOptions
`void` | `RemoteControlConfiguration.copySettingsIntoBrowserOptions(BrowserConfigurationOptions browserOptions)`
`protected BrowserSessionFactory.BrowserSessionInfo` | `BrowserSessionFactory.createNewRemoteSession(java.lang.String browserString, java.lang.String startURL, java.lang.String extensionJs, BrowserConfigurationOptions browserConfiguration, boolean ensureClean, RemoteControlConfiguration configuration)` Creates and tries to open a new session.
`protected java.lang.String` | `SeleniumDriverResourceHandler.getNewBrowserSession(java.lang.String browserString, java.lang.String startURL, java.lang.String extensionJs, BrowserConfigurationOptions browserConfigurations)`
`protected BrowserSessionFactory.BrowserSessionInfo` | `BrowserSessionFactory.getNewBrowserSession(java.lang.String browserString, java.lang.String startURL, java.lang.String extensionJs, BrowserConfigurationOptions browserConfigurations, boolean useCached, boolean ensureClean, RemoteControlConfiguration configuration)` Gets a new browser session
`BrowserSessionFactory.BrowserSessionInfo` | `BrowserSessionFactory.getNewBrowserSession(java.lang.String browserString, java.lang.String startURL, java.lang.String extensionJs, BrowserConfigurationOptions browserConfigurations, RemoteControlConfiguration configuration)` Gets a new browser session, using the SeleniumServer static fields to populate parameters.

Uses of BrowserConfigurationOptions in org.openqa.selenium.server.browserlaunchers

Fields in org.openqa.selenium.server.browserlaunchers declared as BrowserConfigurationOptions
`protected BrowserConfigurationOptions` | `AbstractBrowserLauncher.browserConfigurationOptions`

Methods in org.openqa.selenium.server.browserlaunchers with parameters of type BrowserConfigurationOptions
`BrowserLauncher` | `BrowserLauncherFactory.getBrowserLauncher(java.lang.String browser, java.lang.String sessionId, RemoteControlConfiguration configuration, BrowserConfigurationOptions browserOptions)` Returns the browser given by the specified browser string

Constructors in org.openqa.selenium.server.browserlaunchers with parameters of type BrowserConfigurationOptions
`AbstractBrowserLauncher(java.lang.String sessionId, RemoteControlConfiguration configuration, BrowserConfigurationOptions browserOptions)`
`Firefox2Launcher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`Firefox3Launcher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`FirefoxChromeLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, BrowserInstallation browserInstallation)`
`FirefoxChromeLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserString)`
`FirefoxCustomProfileLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, BrowserInstallation browserInstallation)`
`FirefoxCustomProfileLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`FirefoxLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`GoogleChromeLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, BrowserInstallation browserInstallation)`
`GoogleChromeLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`HTABrowserLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`InternetExplorerCustomProxyLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, BrowserInstallation browserInstallation)`
`InternetExplorerCustomProxyLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`InternetExplorerLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`KonquerorLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`MockBrowserLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String command)`
`OperaCustomProfileLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`ProxyInjectionFirefoxCustomProfileLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, BrowserInstallation browserInstallation)`
`ProxyInjectionFirefoxCustomProfileLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`ProxyInjectionInternetExplorerCustomProxyLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`ProxyInjectionSafariCustomProfileLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`SafariCustomProfileLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`SafariFileBasedLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`SafariLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`

Uses of BrowserConfigurationOptions in org.openqa.selenium.server.htmlrunner

Methods in org.openqa.selenium.server.htmlrunner with parameters of type BrowserConfigurationOptions
`protected BrowserLauncher` | `HTMLLauncher.getBrowserLauncher(java.lang.String browser, java.lang.String sessionId, RemoteControlConfiguration configuration, BrowserConfigurationOptions browserOptions)`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.